require 'eagleclaw/formatters'
require 'eagleclaw/scrapers'
require 'optparse'
require 'ostruct'

module EagleClaw
  class Runner
    attr_accessor :options
    
    def initialize
      @options = OpenStruct.new(:require => [], :format => :json)
    end
    
    def parser
      @parser ||= OptionParser.new do |opts|
        opts.banner = "Usage: #{$0} [options] ScraperName"
        
        # ---- MAIN ----
        
        opts.on('-r', '--require LIBRARY',
                "Require LIBRARY before loading scrapers") do |lib|
          options.require << lib
        end
        
        opts.on('-o', '--output FORMAT',
                "Output data in format FORMAT (default: JSON)") do |format|
          options.format = format.downcase.to_sym
        end
        
        # ---- TAIL ----
        
        opts.on_tail('-h', '--help', "Show this help message") { puts opts and exit }
      end
    end
    
    def parse!(args = ARGV)
      parser.parse!(args)
    end
    
    def run!(args = ARGV)
      parse!(args)
      @options.require.each { |lib| require(lib) }
      formatter = EagleClaw::Formatters[@options.format]
      
      scraper = EagleClaw::Scrapers[args.shift.downcase.to_sym].new
      scraper.run
      data, problems = scraper.data, scraper.problems
      output = formatter.format(data, problems)
      puts output
    end
  end
end
